Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API. +k8s:deepcopy-gen=package +groupName=eventing.knative.dev
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type EventPolicy
- func (ep *EventPolicy) ConvertFrom(ctx context.Context, obj apis.Convertible) error
- func (ep *EventPolicy) ConvertTo(ctx context.Context, obj apis.Convertible) error
- func (in *EventPolicy) DeepCopy() *EventPolicy
- func (in *EventPolicy) DeepCopyInto(out *EventPolicy)
- func (in *EventPolicy) DeepCopyObject() runtime.Object
- func (*EventPolicy) GetConditionSet() apis.ConditionSet
- func (ep *EventPolicy) GetGroupVersionKind() schema.GroupVersionKind
- func (ep *EventPolicy) GetStatus() *duckv1.Status
- func (ep *EventPolicy) GetUntypedSpec() interface{}
- func (ep *EventPolicy) SetDefaults(ctx context.Context)
- func (ep *EventPolicy) Validate(ctx context.Context) *apis.FieldError
- type EventPolicyFromReference
- type EventPolicyList
- type EventPolicySelector
- type EventPolicySpec
- type EventPolicySpecFrom
- type EventPolicySpecTo
- type EventPolicyStatus
- func (in *EventPolicyStatus) DeepCopy() *EventPolicyStatus
- func (in *EventPolicyStatus) DeepCopyInto(out *EventPolicyStatus)
- func (ep *EventPolicyStatus) GetCondition(t apis.ConditionType) *apis.Condition
- func (ep *EventPolicyStatus) GetTopLevelCondition() *apis.Condition
- func (ep *EventPolicyStatus) InitializeConditions()
- func (ep *EventPolicyStatus) IsReady() bool
- func (ep *EventPolicyStatus) MarkOIDCAuthenticationDisabled(reason, messageFormat string, messageA ...interface{})
- func (ep *EventPolicyStatus) MarkOIDCAuthenticationEnabled()
- func (ep *EventPolicyStatus) MarkSubjectsResolvedFailed(reason, messageFormat string, messageA ...interface{})
- func (ep *EventPolicyStatus) MarkSubjectsResolvedSucceeded()
- type EventPolicyToReference
- type EventTransform
- func (in *EventTransform) DeepCopy() *EventTransform
- func (in *EventTransform) DeepCopyInto(out *EventTransform)
- func (in *EventTransform) DeepCopyObject() runtime.Object
- func (et *EventTransform) GetConditionSet() apis.ConditionSet
- func (ep *EventTransform) GetGroupVersionKind() schema.GroupVersionKind
- func (ep *EventTransform) GetStatus() *duckv1.Status
- func (ep *EventTransform) GetUntypedSpec() interface{}
- func (t *EventTransform) SetDefaults(_ context.Context)
- func (t *EventTransform) Validate(ctx context.Context) *apis.FieldError
- type EventTransformList
- type EventTransformSpec
- func (in *EventTransformSpec) CheckImmutableFields(ctx context.Context, original *EventTransform) *apis.FieldError
- func (in *EventTransformSpec) DeepCopy() *EventTransformSpec
- func (in *EventTransformSpec) DeepCopyInto(out *EventTransformSpec)
- func (ts *EventTransformSpec) Validate(ctx context.Context) *apis.FieldError
- type EventTransformStatus
- func (in *EventTransformStatus) DeepCopy() *EventTransformStatus
- func (in *EventTransformStatus) DeepCopyInto(out *EventTransformStatus)
- func (ts *EventTransformStatus) GetCondition(t apis.ConditionType) *apis.Condition
- func (*EventTransformStatus) GetConditionSet() apis.ConditionSet
- func (ts *EventTransformStatus) GetTopLevelCondition() *apis.Condition
- func (ts *EventTransformStatus) InitializeConditions()
- func (ts *EventTransformStatus) IsReady() bool
- func (ts *EventTransformStatus) IsTransformationReady() bool
- func (ts *EventTransformStatus) MarkEventPoliciesFailed(reason, messageFormat string, messageA ...interface{})
- func (ts *EventTransformStatus) MarkEventPoliciesTrue()
- func (ts *EventTransformStatus) MarkEventPoliciesTrueWithReason(reason, messageFormat string, messageA ...interface{})
- func (ts *EventTransformStatus) MarkEventPoliciesUnknown(reason, messageFormat string, messageA ...interface{})
- func (ts *EventTransformStatus) MarkWaitingForServiceEndpoints()
- func (ts *EventTransformStatus) PropagateJsonataCertificateStatus(cs cmv1.CertificateStatus) bool
- func (ts *EventTransformStatus) PropagateJsonataDeploymentStatus(ds appsv1.DeploymentStatus) bool
- func (ts *EventTransformStatus) PropagateJsonataSinkBindingStatus(sbs sourcesv1.SinkBindingStatus) bool
- func (ts *EventTransformStatus) PropagateJsonataSinkBindingUnset()
- func (ts *EventTransformStatus) SetAddresses(addresses ...duckv1.Addressable)
- type EventTransformations
- func (ets EventTransformations) CheckImmutableFields(ctx context.Context, original EventTransformations) *apis.FieldError
- func (in *EventTransformations) DeepCopy() *EventTransformations
- func (in *EventTransformations) DeepCopyInto(out *EventTransformations)
- func (ets EventTransformations) Validate(ctx context.Context, allowEmpty bool) *apis.FieldError
- type JsonataEventTransformationSpec
- type JsonataEventTransformationStatus
- type ReplySpec
- type RequestReply
- func (ep *RequestReply) ConvertFrom(ctx context.Context, obj apis.Convertible) error
- func (ep *RequestReply) ConvertTo(ctx context.Context, obj apis.Convertible) error
- func (in *RequestReply) DeepCopy() *RequestReply
- func (in *RequestReply) DeepCopyInto(out *RequestReply)
- func (in *RequestReply) DeepCopyObject() runtime.Object
- func (*RequestReply) GetConditionSet() apis.ConditionSet
- func (rr *RequestReply) GetGroupVersionKind() schema.GroupVersionKind
- func (rr *RequestReply) GetNamespacedName() types.NamespacedName
- func (rr *RequestReply) GetStatus() *duckv1.Status
- func (rr *RequestReply) GetUntypedSpec() interface{}
- func (rr *RequestReply) SetDefaults(ctx context.Context)
- func (rr *RequestReply) Validate(ctx context.Context) *apis.FieldError
- type RequestReplyList
- type RequestReplySpec
- type RequestReplyStatus
- func (in *RequestReplyStatus) DeepCopy() *RequestReplyStatus
- func (in *RequestReplyStatus) DeepCopyInto(out *RequestReplyStatus)
- func (rr *RequestReplyStatus) GetCondition(t apis.ConditionType) *apis.Condition
- func (*RequestReplyStatus) GetConditionSet() apis.ConditionSet
- func (rr *RequestReplyStatus) GetTopLevelCondition() *apis.Condition
- func (rr *RequestReplyStatus) InitializeConditions()
- func (rr *RequestReplyStatus) IsReady() bool
- func (rr *RequestReplyStatus) MarkBrokerNotReady(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkBrokerReady()
- func (rr *RequestReplyStatus) MarkBrokerUnknown(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkEventPoliciesFailed(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkEventPoliciesTrue()
- func (rr *RequestReplyStatus) MarkEventPoliciesTrueWithReason(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkEventPoliciesUnknown(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkTriggersNotReadyWithReason(reason, messageFormat string, messageA ...interface{})
- func (rr *RequestReplyStatus) MarkTriggersReady()
- func (rr *RequestReplyStatus) SetAddress(address *v1.Addressable)
Constants ¶
const ( EventPolicyConditionReady = apis.ConditionReady EventPolicyConditionAuthenticationEnabled apis.ConditionType = "AuthenticationEnabled" EventPolicyConditionSubjectsResolved apis.ConditionType = "SubjectsResolved" )
const ( TransformConditionAddressable apis.ConditionType = "Addressable" TransformationConditionReady apis.ConditionType = "TransformationReady" TransformationEventPoliciesReady apis.ConditionType = "EventPoliciesReady" TransformationAddressableEmptyURL string = "NoURL" TransformationAddressableWaitingForServiceEndpoints string = "WaitingForServiceEndpoints" // TransformationJsonataDeploymentReady is the condition to indicate that the Jsonata deployment // is ready. TransformationJsonataDeploymentReady apis.ConditionType = "JsonataDeploymentReady" TransformationJsonataCertificateNotReady string = "JsonataCertificateNotReady" // TransformationJsonataSinkBindingReady is the condition to indicate that the Jsonata sink // binding is ready. TransformationJsonataSinkBindingReady apis.ConditionType = "JsonataSinkBindingReady" )
const ( // RequestReplyBrokerAddressStatusAnnotationKey is the RequestReply status // annotation key used to specify the address of the broker RequestReplyBrokerAddressStatusAnnotationKey = "knative.dev/brokerAddress" // RequestReplyBrokerCACertsStatusAnnotationKey is the RequestReply status // annotation key used to specify the broker's Certification Authority (CA) // certificates in PEM format according to // https://www.rfc-editor.org/rfc/rfc7468 RequestReplyBrokerCACertsStatusAnnotationKey = "knative.dev/brokerCACerts" // RequestReplyBrokerAudienceStatusAnnotationKey is the RequestReply status // annotation key used to specify the broker's OIDC audience RequestReplyBrokerAudienceStatusAnnotationKey = "knative.dev/brokerAudience" )
const ( RequestReplyConditionReady = apis.ConditionReady RequestReplyConditionTriggers apis.ConditionType = "TriggersReady" RequestReplyConditionAddressable apis.ConditionType = "Addressable" RequestReplyConditionEventPoliciesReady apis.ConditionType = "EventPoliciesReady" RequestReplyConditionBrokerReady apis.ConditionType = "BrokerReady" )
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: eventing.GroupName, Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
var TransformCondSet = apis.NewLivingConditionSet( TransformationConditionReady, TransformConditionAddressable, TransformationEventPoliciesReady, )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type EventPolicy ¶ added in v0.42.0
type EventPolicy struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec defines the desired state of the EventPolicy.
Spec EventPolicySpec `json:"spec,omitempty"`
// Status represents the current state of the EventPolicy.
// This data may be out of date.
// +optional
Status EventPolicyStatus `json:"status,omitempty"`
}
EventPolicy represents a policy for addressable resources (Broker, Channel, sinks).
func (*EventPolicy) ConvertFrom ¶ added in v0.42.0
func (ep *EventPolicy) ConvertFrom(ctx context.Context, obj apis.Convertible) error
ConvertFrom implements apis.Convertible
func (*EventPolicy) ConvertTo ¶ added in v0.42.0
func (ep *EventPolicy) ConvertTo(ctx context.Context, obj apis.Convertible) error
ConvertTo implements apis.Convertible
func (*EventPolicy) DeepCopy ¶ added in v0.42.0
func (in *EventPolicy) DeepCopy() *EventPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicy.
func (*EventPolicy) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicy) DeepCopyInto(out *EventPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicy) DeepCopyObject ¶ added in v0.42.0
func (in *EventPolicy) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventPolicy) GetConditionSet ¶ added in v0.42.0
func (*EventPolicy) GetConditionSet() apis.ConditionSet
GetConditionSet retrieves the condition set for this resource. Implements the KRShaped interface.
func (*EventPolicy) GetGroupVersionKind ¶ added in v0.42.0
func (ep *EventPolicy) GetGroupVersionKind() schema.GroupVersionKind
GetGroupVersionKind returns GroupVersionKind for EventPolicy
func (*EventPolicy) GetStatus ¶ added in v0.42.0
func (ep *EventPolicy) GetStatus() *duckv1.Status
GetStatus retrieves the status of the EventPolicy. Implements the KRShaped interface.
func (*EventPolicy) GetUntypedSpec ¶ added in v0.42.0
func (ep *EventPolicy) GetUntypedSpec() interface{}
GetUntypedSpec returns the spec of the EventPolicy.
func (*EventPolicy) SetDefaults ¶ added in v0.42.0
func (ep *EventPolicy) SetDefaults(ctx context.Context)
func (*EventPolicy) Validate ¶ added in v0.42.0
func (ep *EventPolicy) Validate(ctx context.Context) *apis.FieldError
type EventPolicyFromReference ¶ added in v0.42.0
type EventPolicyFromReference struct {
// API version of the referent.
APIVersion string `json:"apiVersion,omitempty"`
// Kind of the referent.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
Kind string `json:"kind"`
// Name of the referent.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
Name string `json:"name"`
// Namespace of the referent.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/
// This is optional field, it gets defaulted to the object holding it if left out.
// +optional
Namespace string `json:"namespace,omitempty"`
}
func (*EventPolicyFromReference) DeepCopy ¶ added in v0.42.0
func (in *EventPolicyFromReference) DeepCopy() *EventPolicyFromReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicyFromReference.
func (*EventPolicyFromReference) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicyFromReference) DeepCopyInto(out *EventPolicyFromReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicyFromReference) Validate ¶ added in v0.42.0
func (r *EventPolicyFromReference) Validate() *apis.FieldError
type EventPolicyList ¶ added in v0.42.0
type EventPolicyList struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []EventPolicy `json:"items"`
}
EventPolicyList is a collection of EventPolicy.
func (*EventPolicyList) DeepCopy ¶ added in v0.42.0
func (in *EventPolicyList) DeepCopy() *EventPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicyList.
func (*EventPolicyList) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicyList) DeepCopyInto(out *EventPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicyList) DeepCopyObject ¶ added in v0.42.0
func (in *EventPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventPolicySelector ¶ added in v0.42.0
type EventPolicySelector struct {
*metav1.LabelSelector `json:",inline"`
*metav1.TypeMeta `json:",inline"`
}
func (*EventPolicySelector) DeepCopy ¶ added in v0.42.0
func (in *EventPolicySelector) DeepCopy() *EventPolicySelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicySelector.
func (*EventPolicySelector) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicySelector) DeepCopyInto(out *EventPolicySelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventPolicySpec ¶ added in v0.42.0
type EventPolicySpec struct {
// To lists all resources for which this policy applies.
// Resources in this list must act like an ingress and have an audience.
// The resources are part of the same namespace as the EventPolicy.
// An empty list means it applies to all resources in the EventPolicies namespace
// +optional
To []EventPolicySpecTo `json:"to,omitempty"`
// From is the list of sources or oidc identities, which are allowed to send events to the targets (.spec.to).
From []EventPolicySpecFrom `json:"from,omitempty"`
// Filters is the list of SubscriptoinsApi filters which determine whether or not the event is accepted.
// It is an array of filter expressions that evaluate to true or false.
// If any filter expression in the array evaluates to false, the event will not
// pass the target resource's ingress. Absence of any filters implies that the filters
// always evaluate to true.
// +optional
Filters []eventingv1.SubscriptionsAPIFilter `json:"filters,omitempty"`
}
func (*EventPolicySpec) DeepCopy ¶ added in v0.42.0
func (in *EventPolicySpec) DeepCopy() *EventPolicySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicySpec.
func (*EventPolicySpec) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicySpec) DeepCopyInto(out *EventPolicySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicySpec) SetDefaults ¶ added in v0.42.0
func (ets *EventPolicySpec) SetDefaults(ctx context.Context)
func (*EventPolicySpec) Validate ¶ added in v0.42.0
func (ets *EventPolicySpec) Validate(ctx context.Context) *apis.FieldError
type EventPolicySpecFrom ¶ added in v0.42.0
type EventPolicySpecFrom struct {
// Ref contains a direct reference to a resource which is allowed to send events to the target.
// +optional
Ref *EventPolicyFromReference `json:"ref,omitempty"`
// Sub sets the OIDC identity name to be allowed to send events to the target.
// It is also possible to set a glob-like pattern to match any suffix.
// +optional
Sub *string `json:"sub,omitempty"`
}
func (*EventPolicySpecFrom) DeepCopy ¶ added in v0.42.0
func (in *EventPolicySpecFrom) DeepCopy() *EventPolicySpecFrom
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicySpecFrom.
func (*EventPolicySpecFrom) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicySpecFrom) DeepCopyInto(out *EventPolicySpecFrom)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicySpecFrom) SetDefaults ¶ added in v0.43.0
func (from *EventPolicySpecFrom) SetDefaults(ctx context.Context)
type EventPolicySpecTo ¶ added in v0.42.0
type EventPolicySpecTo struct {
// Ref contains the direct reference to a target
// +optional
Ref *EventPolicyToReference `json:"ref,omitempty"`
// Selector contains a selector to group targets
// +optional
Selector *EventPolicySelector `json:"selector,omitempty"`
}
func (*EventPolicySpecTo) DeepCopy ¶ added in v0.42.0
func (in *EventPolicySpecTo) DeepCopy() *EventPolicySpecTo
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicySpecTo.
func (*EventPolicySpecTo) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicySpecTo) DeepCopyInto(out *EventPolicySpecTo)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventPolicyStatus ¶ added in v0.42.0
type EventPolicyStatus struct {
// inherits duck/v1 Status, which currently provides:
// * ObservedGeneration - the 'Generation' of the Service that was last processed by the controller.
// * Conditions - the latest available observations of a resource's current state.
duckv1.Status `json:",inline"`
// From is the list of resolved oidc identities from .spec.from
From []string `json:"from,omitempty"`
}
EventPolicyStatus represents the current state of a EventPolicy.
func (*EventPolicyStatus) DeepCopy ¶ added in v0.42.0
func (in *EventPolicyStatus) DeepCopy() *EventPolicyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicyStatus.
func (*EventPolicyStatus) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicyStatus) DeepCopyInto(out *EventPolicyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicyStatus) GetCondition ¶ added in v0.42.0
func (ep *EventPolicyStatus) GetCondition(t apis.ConditionType) *apis.Condition
GetCondition returns the condition currently associated with the given type, or nil.
func (*EventPolicyStatus) GetTopLevelCondition ¶ added in v0.42.0
func (ep *EventPolicyStatus) GetTopLevelCondition() *apis.Condition
GetTopLevelCondition returns the top level Condition.
func (*EventPolicyStatus) InitializeConditions ¶ added in v0.42.0
func (ep *EventPolicyStatus) InitializeConditions()
InitializeConditions sets relevant unset conditions to Unknown state.
func (*EventPolicyStatus) IsReady ¶ added in v0.42.0
func (ep *EventPolicyStatus) IsReady() bool
IsReady returns true if the resource is ready overall.
func (*EventPolicyStatus) MarkOIDCAuthenticationDisabled ¶ added in v0.42.0
func (ep *EventPolicyStatus) MarkOIDCAuthenticationDisabled(reason, messageFormat string, messageA ...interface{})
MarkOIDCAuthenticationDisabled sets EventPolicyConditionAuthenticationEnabled condition to false.
func (*EventPolicyStatus) MarkOIDCAuthenticationEnabled ¶ added in v0.42.0
func (ep *EventPolicyStatus) MarkOIDCAuthenticationEnabled()
MarkOIDCAuthenticationEnabled sets EventPolicyConditionAuthenticationEnabled condition to true.
func (*EventPolicyStatus) MarkSubjectsResolvedFailed ¶ added in v0.42.0
func (ep *EventPolicyStatus) MarkSubjectsResolvedFailed(reason, messageFormat string, messageA ...interface{})
MarkSubjectsNotResolved sets EventPolicyConditionSubjectsResolved condition to false.
func (*EventPolicyStatus) MarkSubjectsResolvedSucceeded ¶ added in v0.42.0
func (ep *EventPolicyStatus) MarkSubjectsResolvedSucceeded()
MarkSubjectsResolved sets EventPolicyConditionSubjectsResolved condition to true.
type EventPolicyToReference ¶ added in v0.42.0
type EventPolicyToReference struct {
// API version of the referent.
APIVersion string `json:"apiVersion,omitempty"`
// Kind of the referent.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
Kind string `json:"kind"`
// Name of the referent.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
Name string `json:"name"`
}
func (*EventPolicyToReference) DeepCopy ¶ added in v0.42.0
func (in *EventPolicyToReference) DeepCopy() *EventPolicyToReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventPolicyToReference.
func (*EventPolicyToReference) DeepCopyInto ¶ added in v0.42.0
func (in *EventPolicyToReference) DeepCopyInto(out *EventPolicyToReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventPolicyToReference) Validate ¶ added in v0.42.0
func (r *EventPolicyToReference) Validate() *apis.FieldError
type EventTransform ¶ added in v0.45.0
type EventTransform struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec defines the desired state of the EventTransform.
Spec EventTransformSpec `json:"spec,omitempty"`
// Status represents the current state of the EventTransform.
// This data may be out of date.
// +optional
Status EventTransformStatus `json:"status,omitempty"`
}
EventTransform represents an even transformation.
func (*EventTransform) DeepCopy ¶ added in v0.45.0
func (in *EventTransform) DeepCopy() *EventTransform
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventTransform.
func (*EventTransform) DeepCopyInto ¶ added in v0.45.0
func (in *EventTransform) DeepCopyInto(out *EventTransform)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventTransform) DeepCopyObject ¶ added in v0.45.0
func (in *EventTransform) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventTransform) GetConditionSet ¶ added in v0.45.0
func (et *EventTransform) GetConditionSet() apis.ConditionSet
GetConditionSet retrieves the condition set for this resource. Implements the KRShaped interface.
func (*EventTransform) GetGroupVersionKind ¶ added in v0.45.0
func (ep *EventTransform) GetGroupVersionKind() schema.GroupVersionKind
GetGroupVersionKind returns GroupVersionKind for EventTransform
func (*EventTransform) GetStatus ¶ added in v0.45.0
func (ep *EventTransform) GetStatus() *duckv1.Status
GetStatus retrieves the status of the EventTransform. Implements the KRShaped interface.
func (*EventTransform) GetUntypedSpec ¶ added in v0.45.0
func (ep *EventTransform) GetUntypedSpec() interface{}
GetUntypedSpec returns the spec of the EventTransform.
func (*EventTransform) SetDefaults ¶ added in v0.45.0
func (t *EventTransform) SetDefaults(_ context.Context)
func (*EventTransform) Validate ¶ added in v0.45.0
func (t *EventTransform) Validate(ctx context.Context) *apis.FieldError
type EventTransformList ¶ added in v0.45.0
type EventTransformList struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []EventTransform `json:"items"`
}
EventTransformList is a collection of EventTransform.
func (*EventTransformList) DeepCopy ¶ added in v0.45.0
func (in *EventTransformList) DeepCopy() *EventTransformList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventTransformList.
func (*EventTransformList) DeepCopyInto ¶ added in v0.45.0
func (in *EventTransformList) DeepCopyInto(out *EventTransformList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventTransformList) DeepCopyObject ¶ added in v0.45.0
func (in *EventTransformList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventTransformSpec ¶ added in v0.45.0
type EventTransformSpec struct {
// Sink is a reference to an object that will resolve to a uri to use as the sink.
//
// If not present, the transformation will send back the transformed event as response, this
// is useful to leverage the built-in Broker reply feature to re-publish a transformed event
// back to the broker.
//
// +optional
Sink *duckv1.Destination `json:"sink,omitempty"`
// Reply is the configuration on how to handle responses from Sink.
// It can only be set if Sink is set.
//
// +optional
Reply *ReplySpec `json:"reply,omitempty"`
// EventTransformations contain all possible transformations, only one "type" can be used.
EventTransformations `json:",inline"`
}
func (*EventTransformSpec) CheckImmutableFields ¶ added in v0.45.0
func (in *EventTransformSpec) CheckImmutableFields(ctx context.Context, original *EventTransform) *apis.FieldError
func (*EventTransformSpec) DeepCopy ¶ added in v0.45.0
func (in *EventTransformSpec) DeepCopy() *EventTransformSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventTransformSpec.
func (*EventTransformSpec) DeepCopyInto ¶ added in v0.45.0
func (in *EventTransformSpec) DeepCopyInto(out *EventTransformSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventTransformSpec) Validate ¶ added in v0.45.0
func (ts *EventTransformSpec) Validate(ctx context.Context) *apis.FieldError
type EventTransformStatus ¶ added in v0.45.0
type EventTransformStatus struct {
// SourceStatus inherits duck/v1 SourceStatus, which currently provides:
// * ObservedGeneration - the 'Generation' of the Service that was last
// processed by the controller.
// * Conditions - the latest available observations of a resource's current
// state.
// * SinkURI - the current active sink URI that has been configured for the
// Source.
duckv1.SourceStatus `json:",inline"`
// AddressStatus is the part where the EventTransform fulfills the Addressable contract.
// It exposes the endpoint as an URI to get events delivered.
// +optional
duckv1.AddressStatus `json:",inline"`
// AppliedEventPoliciesStatus contains the list of EventPolicies which apply to this EventTransform.
// +optional
eventingduckv1.AppliedEventPoliciesStatus `json:",inline"`
// JsonataTransformationStatus is the status associated with JsonataEventTransformationSpec.
// +optional
JsonataTransformationStatus *JsonataEventTransformationStatus `json:"jsonata,omitempty"`
}
EventTransformStatus represents the current state of a EventTransform.
func (*EventTransformStatus) DeepCopy ¶ added in v0.45.0
func (in *EventTransformStatus) DeepCopy() *EventTransformStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventTransformStatus.
func (*EventTransformStatus) DeepCopyInto ¶ added in v0.45.0
func (in *EventTransformStatus) DeepCopyInto(out *EventTransformStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventTransformStatus) GetCondition ¶ added in v0.45.0
func (ts *EventTransformStatus) GetCondition(t apis.ConditionType) *apis.Condition
GetCondition returns the condition cutsently associated with the given type, or nil.
func (*EventTransformStatus) GetConditionSet ¶ added in v0.45.0
func (*EventTransformStatus) GetConditionSet() apis.ConditionSet
func (*EventTransformStatus) GetTopLevelCondition ¶ added in v0.45.0
func (ts *EventTransformStatus) GetTopLevelCondition() *apis.Condition
GetTopLevelCondition returns the top level Condition.
func (*EventTransformStatus) InitializeConditions ¶ added in v0.45.0
func (ts *EventTransformStatus) InitializeConditions()
InitializeConditions sets relevant unset conditions to Unknown state.
func (*EventTransformStatus) IsReady ¶ added in v0.45.0
func (ts *EventTransformStatus) IsReady() bool
IsReady returns true if the resource is ready overall.
func (*EventTransformStatus) IsTransformationReady ¶ added in v0.45.0
func (ts *EventTransformStatus) IsTransformationReady() bool
func (*EventTransformStatus) MarkEventPoliciesFailed ¶ added in v0.49.0
func (ts *EventTransformStatus) MarkEventPoliciesFailed(reason, messageFormat string, messageA ...interface{})
func (*EventTransformStatus) MarkEventPoliciesTrue ¶ added in v0.49.0
func (ts *EventTransformStatus) MarkEventPoliciesTrue()
func (*EventTransformStatus) MarkEventPoliciesTrueWithReason ¶ added in v0.49.0
func (ts *EventTransformStatus) MarkEventPoliciesTrueWithReason(reason, messageFormat string, messageA ...interface{})
func (*EventTransformStatus) MarkEventPoliciesUnknown ¶ added in v0.49.0
func (ts *EventTransformStatus) MarkEventPoliciesUnknown(reason, messageFormat string, messageA ...interface{})
func (*EventTransformStatus) MarkWaitingForServiceEndpoints ¶ added in v0.45.0
func (ts *EventTransformStatus) MarkWaitingForServiceEndpoints()
func (*EventTransformStatus) PropagateJsonataCertificateStatus ¶ added in v0.45.0
func (ts *EventTransformStatus) PropagateJsonataCertificateStatus(cs cmv1.CertificateStatus) bool
func (*EventTransformStatus) PropagateJsonataDeploymentStatus ¶ added in v0.45.0
func (ts *EventTransformStatus) PropagateJsonataDeploymentStatus(ds appsv1.DeploymentStatus) bool
func (*EventTransformStatus) PropagateJsonataSinkBindingStatus ¶ added in v0.45.0
func (ts *EventTransformStatus) PropagateJsonataSinkBindingStatus(sbs sourcesv1.SinkBindingStatus) bool
func (*EventTransformStatus) PropagateJsonataSinkBindingUnset ¶ added in v0.45.0
func (ts *EventTransformStatus) PropagateJsonataSinkBindingUnset()
func (*EventTransformStatus) SetAddresses ¶ added in v0.45.0
func (ts *EventTransformStatus) SetAddresses(addresses ...duckv1.Addressable)
type EventTransformations ¶ added in v0.45.0
type EventTransformations struct {
Jsonata *JsonataEventTransformationSpec `json:"jsonata,omitempty"`
}
func (EventTransformations) CheckImmutableFields ¶ added in v0.45.0
func (ets EventTransformations) CheckImmutableFields(ctx context.Context, original EventTransformations) *apis.FieldError
func (*EventTransformations) DeepCopy ¶ added in v0.45.0
func (in *EventTransformations) DeepCopy() *EventTransformations
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventTransformations.
func (*EventTransformations) DeepCopyInto ¶ added in v0.45.0
func (in *EventTransformations) DeepCopyInto(out *EventTransformations)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (EventTransformations) Validate ¶ added in v0.45.0
func (ets EventTransformations) Validate(ctx context.Context, allowEmpty bool) *apis.FieldError
type JsonataEventTransformationSpec ¶ added in v0.45.0
type JsonataEventTransformationSpec struct {
// Expression is the JSONata expression.
Expression string `json:"expression,omitempty"`
}
func (*JsonataEventTransformationSpec) DeepCopy ¶ added in v0.45.0
func (in *JsonataEventTransformationSpec) DeepCopy() *JsonataEventTransformationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JsonataEventTransformationSpec.
func (*JsonataEventTransformationSpec) DeepCopyInto ¶ added in v0.45.0
func (in *JsonataEventTransformationSpec) DeepCopyInto(out *JsonataEventTransformationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*JsonataEventTransformationSpec) Validate ¶ added in v0.45.0
func (js *JsonataEventTransformationSpec) Validate(context.Context) *apis.FieldError
type JsonataEventTransformationStatus ¶ added in v0.45.0
type JsonataEventTransformationStatus struct {
Deployment appsv1.DeploymentStatus `json:"deployment,omitempty"`
}
func (*JsonataEventTransformationStatus) DeepCopy ¶ added in v0.45.0
func (in *JsonataEventTransformationStatus) DeepCopy() *JsonataEventTransformationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JsonataEventTransformationStatus.
func (*JsonataEventTransformationStatus) DeepCopyInto ¶ added in v0.45.0
func (in *JsonataEventTransformationStatus) DeepCopyInto(out *JsonataEventTransformationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReplySpec ¶ added in v0.45.0
type ReplySpec struct {
// EventTransformations for replies from the Sink, contain all possible transformations,
// only one "type" can be used.
//
// The used type must match the top-level transformation, if you need to mix transformation types,
// use compositions and chain transformations together to achieve your desired outcome.
EventTransformations `json:",inline"`
// Discard discards responses from Sink and return empty response body.
//
// When set to false, it returns the exact sink response body.
// When set to true, Discard is mutually exclusive with EventTransformations in the reply
// section, it can either be discarded or transformed.
//
// Default: false.
//
// +optional
Discard *bool `json:"discard,omitempty"`
}
ReplySpec is the configurations on how to handle responses from Sink.
func (*ReplySpec) CheckImmutableFields ¶ added in v0.45.0
func (*ReplySpec) DeepCopy ¶ added in v0.45.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReplySpec.
func (*ReplySpec) DeepCopyInto ¶ added in v0.45.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ReplySpec) Validate ¶ added in v0.45.0
func (rs *ReplySpec) Validate(ctx context.Context, ts *EventTransformSpec) *apis.FieldError
type RequestReply ¶ added in v0.44.0
type RequestReply struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec defines the desired state of the EventPolicy.
Spec RequestReplySpec `json:"spec,omitempty"`
// Status represents the current state of the EventPolicy.
// This data may be out of date.
// +optional
Status RequestReplyStatus `json:"status,omitempty"`
}
RequestReply represents synchronous interface to sending and receiving events from a Broker.
func (*RequestReply) ConvertFrom ¶ added in v0.44.0
func (ep *RequestReply) ConvertFrom(ctx context.Context, obj apis.Convertible) error
ConvertFrom implements apis.Convertible
func (*RequestReply) ConvertTo ¶ added in v0.44.0
func (ep *RequestReply) ConvertTo(ctx context.Context, obj apis.Convertible) error
ConvertTo implements apis.Convertible
func (*RequestReply) DeepCopy ¶ added in v0.44.0
func (in *RequestReply) DeepCopy() *RequestReply
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RequestReply.
func (*RequestReply) DeepCopyInto ¶ added in v0.44.0
func (in *RequestReply) DeepCopyInto(out *RequestReply)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RequestReply) DeepCopyObject ¶ added in v0.44.0
func (in *RequestReply) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*RequestReply) GetConditionSet ¶ added in v0.44.0
func (*RequestReply) GetConditionSet() apis.ConditionSet
GetConditionSet retrieves the condition set for this resource. Implements the KRShaped interface.
func (*RequestReply) GetGroupVersionKind ¶ added in v0.44.0
func (rr *RequestReply) GetGroupVersionKind() schema.GroupVersionKind
GetGroupVersionKind returns GroupVersionKind for EventPolicy
func (*RequestReply) GetNamespacedName ¶ added in v0.47.0
func (rr *RequestReply) GetNamespacedName() types.NamespacedName
func (*RequestReply) GetStatus ¶ added in v0.44.0
func (rr *RequestReply) GetStatus() *duckv1.Status
GetStatus retrieves the status of the EventPolicy. Implements the KRShaped interface.
func (*RequestReply) GetUntypedSpec ¶ added in v0.44.0
func (rr *RequestReply) GetUntypedSpec() interface{}
GetUntypedSpec returns the spec of the EventPolicy.
func (*RequestReply) SetDefaults ¶ added in v0.44.0
func (rr *RequestReply) SetDefaults(ctx context.Context)
func (*RequestReply) Validate ¶ added in v0.44.0
func (rr *RequestReply) Validate(ctx context.Context) *apis.FieldError
type RequestReplyList ¶ added in v0.44.0
type RequestReplyList struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []RequestReply `json:"items"`
}
RequestReplyList is a collection of RequestReplies.
func (*RequestReplyList) DeepCopy ¶ added in v0.44.0
func (in *RequestReplyList) DeepCopy() *RequestReplyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RequestReplyList.
func (*RequestReplyList) DeepCopyInto ¶ added in v0.44.0
func (in *RequestReplyList) DeepCopyInto(out *RequestReplyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RequestReplyList) DeepCopyObject ¶ added in v0.44.0
func (in *RequestReplyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RequestReplySpec ¶ added in v0.44.0
type RequestReplySpec struct {
// BrokerRef contains the reference to the broker the RequestReply sends events to.
BrokerRef duckv1.KReference `json:"brokerRef"`
CorrelationAttribute string `json:"correlationAttribute"`
ReplyAttribute string `json:"replyAttribute"`
Timeout *string `json:"timeout,omitempty"`
Delivery *eventingduckv1.DeliverySpec `json:"delivery,omitempty"`
}
func (*RequestReplySpec) DeepCopy ¶ added in v0.44.0
func (in *RequestReplySpec) DeepCopy() *RequestReplySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RequestReplySpec.
func (*RequestReplySpec) DeepCopyInto ¶ added in v0.44.0
func (in *RequestReplySpec) DeepCopyInto(out *RequestReplySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RequestReplySpec) SetDefaults ¶ added in v0.44.0
func (rrs *RequestReplySpec) SetDefaults(ctx context.Context)
func (*RequestReplySpec) Validate ¶ added in v0.44.0
func (rrs *RequestReplySpec) Validate(ctx context.Context) *apis.FieldError
type RequestReplyStatus ¶ added in v0.44.0
type RequestReplyStatus struct {
// inherits duck/v1 Status, which currently provides:
// * ObservedGeneration - the 'Generation' of the Service that was last processed by the controller.
// * Conditions - the latest available observations of a resource's current state.
duckv1.Status `json:",inline"`
// AddressStatus is the part where the RequestReply fulfills the Addressable contract.
// It exposes the endpoint as an URI to get events delivered.
// +optional
duckv1.AddressStatus `json:",inline"`
// AppliedEventPoliciesStatus contains the list of EventPolicies which apply to this Broker.
// +optional
eventingduckv1.AppliedEventPoliciesStatus `json:",inline"`
// DesiredReplicas is the number of replicas (StatefulSet pod + trigger) that is desired
DesiredReplicas *int32 `json:"desiredReplicas,omitempty"`
// ReadyReplicas is the number of ready replicas (StatefulSet pod + trigger) for this RequestReply resource
ReadyReplicas *int32 `json:"readyReplicas,omitempty"`
}
RequestReplyStatus represents the current state of a RequestReply.
func (*RequestReplyStatus) DeepCopy ¶ added in v0.44.0
func (in *RequestReplyStatus) DeepCopy() *RequestReplyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RequestReplyStatus.
func (*RequestReplyStatus) DeepCopyInto ¶ added in v0.44.0
func (in *RequestReplyStatus) DeepCopyInto(out *RequestReplyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RequestReplyStatus) GetCondition ¶ added in v0.44.0
func (rr *RequestReplyStatus) GetCondition(t apis.ConditionType) *apis.Condition
GetCondition returns the condition currently associated with the given type, or nil.
func (*RequestReplyStatus) GetConditionSet ¶ added in v0.44.0
func (*RequestReplyStatus) GetConditionSet() apis.ConditionSet
func (*RequestReplyStatus) GetTopLevelCondition ¶ added in v0.44.0
func (rr *RequestReplyStatus) GetTopLevelCondition() *apis.Condition
GetTopLevelCondition returns the top level Condition.
func (*RequestReplyStatus) InitializeConditions ¶ added in v0.44.0
func (rr *RequestReplyStatus) InitializeConditions()
InitializeConditions sets relevant unset conditions to Unknown state.
func (*RequestReplyStatus) IsReady ¶ added in v0.44.0
func (rr *RequestReplyStatus) IsReady() bool
IsReady returns true if the resource is ready overall.
func (*RequestReplyStatus) MarkBrokerNotReady ¶ added in v0.47.0
func (rr *RequestReplyStatus) MarkBrokerNotReady(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkBrokerReady ¶ added in v0.47.0
func (rr *RequestReplyStatus) MarkBrokerReady()
func (*RequestReplyStatus) MarkBrokerUnknown ¶ added in v0.47.0
func (rr *RequestReplyStatus) MarkBrokerUnknown(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkEventPoliciesFailed ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkEventPoliciesFailed(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkEventPoliciesTrue ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkEventPoliciesTrue()
func (*RequestReplyStatus) MarkEventPoliciesTrueWithReason ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkEventPoliciesTrueWithReason(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkEventPoliciesUnknown ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkEventPoliciesUnknown(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkTriggersNotReadyWithReason ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkTriggersNotReadyWithReason(reason, messageFormat string, messageA ...interface{})
func (*RequestReplyStatus) MarkTriggersReady ¶ added in v0.44.0
func (rr *RequestReplyStatus) MarkTriggersReady()
func (*RequestReplyStatus) SetAddress ¶ added in v0.44.0
func (rr *RequestReplyStatus) SetAddress(address *v1.Addressable)
Source Files
¶
- doc.go
- eventpolicy_conversion.go
- eventpolicy_defaults.go
- eventpolicy_lifecycle.go
- eventpolicy_types.go
- eventpolicy_validation.go
- eventtransform_defaults.go
- eventtransform_lifecycle.go
- eventtransform_types.go
- eventtransform_validation.go
- register.go
- requestreply_conversion.go
- requestreply_defaults.go
- requestreply_lifecycle.go
- requestreply_types.go
- requestreply_validation.go
- zz_generated.deepcopy.go