Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API. +k8s:deepcopy-gen=package +groupName=flows.knative.dev
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type Parallel
- func (sink *Parallel) ConvertFrom(ctx context.Context, obj apis.Convertible) error
- func (source *Parallel) ConvertTo(ctx context.Context, obj apis.Convertible) error
- func (in *Parallel) DeepCopy() *Parallel
- func (in *Parallel) DeepCopyInto(out *Parallel)
- func (in *Parallel) DeepCopyObject() runtime.Object
- func (p *Parallel) GetGroupVersionKind() schema.GroupVersionKind
- func (p *Parallel) GetUntypedSpec() interface{}
- func (p *Parallel) SetDefaults(ctx context.Context)
- func (p *Parallel) Validate(ctx context.Context) *apis.FieldError
- type ParallelBranch
- type ParallelBranchStatus
- type ParallelChannelStatus
- type ParallelList
- type ParallelSpec
- type ParallelStatus
- func (ps *ParallelStatus) ClearDeprecated()
- func (in *ParallelStatus) DeepCopy() *ParallelStatus
- func (in *ParallelStatus) DeepCopyInto(out *ParallelStatus)
- func (ps *ParallelStatus) GetCondition(t apis.ConditionType) *apis.Condition
- func (ps *ParallelStatus) InitializeConditions()
- func (ps *ParallelStatus) IsReady() bool
- func (ps *ParallelStatus) MarkAddressableNotReady(reason, messageFormat string, messageA ...interface{})
- func (ps *ParallelStatus) MarkChannelsNotReady(reason, messageFormat string, messageA ...interface{})
- func (ps *ParallelStatus) MarkDestinationDeprecatedRef(reason, msg string)
- func (ps *ParallelStatus) MarkSubscriptionsNotReady(reason, messageFormat string, messageA ...interface{})
- func (ps *ParallelStatus) PropagateChannelStatuses(ingressChannel *duckv1alpha1.Channelable, channels []*duckv1alpha1.Channelable)
- func (ps *ParallelStatus) PropagateSubscriptionStatuses(filterSubscriptions []*messagingv1alpha1.Subscription, ...)
- type ParallelSubscriptionStatus
- type Sequence
- func (sink *Sequence) ConvertFrom(ctx context.Context, obj apis.Convertible) error
- func (source *Sequence) ConvertTo(ctx context.Context, obj apis.Convertible) error
- func (in *Sequence) DeepCopy() *Sequence
- func (in *Sequence) DeepCopyInto(out *Sequence)
- func (in *Sequence) DeepCopyObject() runtime.Object
- func (p *Sequence) GetGroupVersionKind() schema.GroupVersionKind
- func (s *Sequence) GetUntypedSpec() interface{}
- func (s *Sequence) SetDefaults(ctx context.Context)
- func (p *Sequence) Validate(ctx context.Context) *apis.FieldError
- type SequenceChannelStatus
- type SequenceList
- type SequenceSpec
- type SequenceStatus
- func (in *SequenceStatus) DeepCopy() *SequenceStatus
- func (in *SequenceStatus) DeepCopyInto(out *SequenceStatus)
- func (ss *SequenceStatus) GetCondition(t apis.ConditionType) *apis.Condition
- func (ss *SequenceStatus) InitializeConditions()
- func (ss *SequenceStatus) IsReady() bool
- func (ss *SequenceStatus) MarkAddressableNotReady(reason, messageFormat string, messageA ...interface{})
- func (ss *SequenceStatus) MarkChannelsNotReady(reason, messageFormat string, messageA ...interface{})
- func (ss *SequenceStatus) MarkSubscriptionsNotReady(reason, messageFormat string, messageA ...interface{})
- func (ss *SequenceStatus) PropagateChannelStatuses(channels []*duckv1alpha1.Channelable)
- func (ss *SequenceStatus) PropagateSubscriptionStatuses(subscriptions []*messagingv1alpha1.Subscription)
- type SequenceStep
- type SequenceSubscriptionStatus
Constants ¶
const ( // ParallelConditionReady has status True when all subconditions below have been set to True. ParallelConditionReady = apis.ConditionReady // ParallelConditionChannelsReady has status True when all the channels created as part of // this parallel are ready. ParallelConditionChannelsReady apis.ConditionType = "ChannelsReady" // ParallelConditionSubscriptionsReady has status True when all the subscriptions created as part of // this parallel are ready. ParallelConditionSubscriptionsReady apis.ConditionType = "SubscriptionsReady" // ParallelConditionAddressable has status true when this Parallel meets // the Addressable contract and has a non-empty hostname. ParallelConditionAddressable apis.ConditionType = "Addressable" )
const ( // SequenceConditionReady has status True when all subconditions below have been set to True. SequenceConditionReady = apis.ConditionReady // SequenceChannelsReady has status True when all the channels created as part of // this sequence are ready. SequenceConditionChannelsReady apis.ConditionType = "ChannelsReady" // SequenceSubscriptionsReady has status True when all the subscriptions created as part of // this sequence are ready. SequenceConditionSubscriptionsReady apis.ConditionType = "SubscriptionsReady" // SequenceConditionAddressable has status true when this Sequence meets // the Addressable contract and has a non-empty hostname. SequenceConditionAddressable apis.ConditionType = "Addressable" )
const ( // StatusConditionTypeDeprecated is the status.conditions.type used to provide deprecation // warnings. StatusConditionTypeDeprecated = "Deprecated" )
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: flows.GroupName, Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Parallel ¶
type Parallel struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec defines the desired state of the Parallel.
Spec ParallelSpec `json:"spec,omitempty"`
// Status represents the current state of the Parallel. This data may be out of
// date.
// +optional
Status ParallelStatus `json:"status,omitempty"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object Parallel defines conditional branches that will be wired in series through Channels and Subscriptions.
func (*Parallel) ConvertFrom ¶ added in v0.13.0
ConvertFrom implements apis.Convertible Converts obj from v1beta1.Sequence into v1alpha1.Sequence
func (*Parallel) ConvertTo ¶ added in v0.13.0
ConvertTo implements apis.Convertible Converts obj from v1alpha1.Parallel into v1beta1.Parallel
func (*Parallel) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Parallel.
func (*Parallel) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Parallel) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Parallel) GetGroupVersionKind ¶
func (p *Parallel) GetGroupVersionKind() schema.GroupVersionKind
GetGroupVersionKind returns GroupVersionKind for Parallel
func (*Parallel) GetUntypedSpec ¶
func (p *Parallel) GetUntypedSpec() interface{}
GetUntypedSpec returns the spec of the Parallel.
func (*Parallel) SetDefaults ¶
type ParallelBranch ¶
type ParallelBranch struct {
// Filter is the expression guarding the branch
Filter *duckv1.Destination `json:"filter,omitempty"`
// Subscriber receiving the event when the filter passes
Subscriber duckv1.Destination `json:"subscriber"`
// Reply is a Reference to where the result of Subscriber of this case gets sent to.
// If not specified, sent the result to the Parallel Reply
// +optional
Reply *duckv1.Destination `json:"reply,omitempty"`
// Delivery is the delivery specification for events to the subscriber
// This includes things like retries, DLQ, etc.
// Needed for Roundtripping v1alpha1 <-> v1beta1.
// +optional
Delivery *eventingduckv1beta1.DeliverySpec `json:"delivery,omitempty"`
}
func (*ParallelBranch) DeepCopy ¶
func (in *ParallelBranch) DeepCopy() *ParallelBranch
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelBranch.
func (*ParallelBranch) DeepCopyInto ¶
func (in *ParallelBranch) DeepCopyInto(out *ParallelBranch)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ParallelBranchStatus ¶
type ParallelBranchStatus struct {
// FilterSubscriptionStatus corresponds to the filter subscription status.
FilterSubscriptionStatus ParallelSubscriptionStatus `json:"filterSubscriptionStatus"`
// FilterChannelStatus corresponds to the filter channel status.
FilterChannelStatus ParallelChannelStatus `json:"filterChannelStatus"`
// SubscriptionStatus corresponds to the subscriber subscription status.
SubscriptionStatus ParallelSubscriptionStatus `json:"subscriberSubscriptionStatus"`
}
ParallelBranchStatus represents the current state of a Parallel branch
func (*ParallelBranchStatus) DeepCopy ¶
func (in *ParallelBranchStatus) DeepCopy() *ParallelBranchStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelBranchStatus.
func (*ParallelBranchStatus) DeepCopyInto ¶
func (in *ParallelBranchStatus) DeepCopyInto(out *ParallelBranchStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ParallelChannelStatus ¶
type ParallelChannelStatus struct {
// Channel is the reference to the underlying channel.
Channel corev1.ObjectReference `json:"channel"`
// ReadyCondition indicates whether the Channel is ready or not.
ReadyCondition apis.Condition `json:"ready"`
}
func (*ParallelChannelStatus) DeepCopy ¶
func (in *ParallelChannelStatus) DeepCopy() *ParallelChannelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelChannelStatus.
func (*ParallelChannelStatus) DeepCopyInto ¶
func (in *ParallelChannelStatus) DeepCopyInto(out *ParallelChannelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ParallelList ¶
type ParallelList struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []Parallel `json:"items"`
}
ParallelList is a collection of Parallels.
func (*ParallelList) DeepCopy ¶
func (in *ParallelList) DeepCopy() *ParallelList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelList.
func (*ParallelList) DeepCopyInto ¶
func (in *ParallelList) DeepCopyInto(out *ParallelList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ParallelList) DeepCopyObject ¶
func (in *ParallelList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ParallelSpec ¶
type ParallelSpec struct {
// Branches is the list of Filter/Subscribers pairs.
Branches []ParallelBranch `json:"branches"`
// ChannelTemplate specifies which Channel CRD to use. If left unspecified, it is set to the default Channel CRD
// for the namespace (or cluster, in case there are no defaults for the namespace).
// +optional
ChannelTemplate *messagingduckv1beta1.ChannelTemplateSpec `json:"channelTemplate"`
// Reply is a Reference to where the result of a case Subscriber gets sent to
// when the case does not have a Reply
// +optional
Reply *duckv1.Destination `json:"reply,omitempty"`
}
func (*ParallelSpec) DeepCopy ¶
func (in *ParallelSpec) DeepCopy() *ParallelSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelSpec.
func (*ParallelSpec) DeepCopyInto ¶
func (in *ParallelSpec) DeepCopyInto(out *ParallelSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ParallelSpec) SetDefaults ¶
func (ps *ParallelSpec) SetDefaults(ctx context.Context)
func (*ParallelSpec) Validate ¶
func (ps *ParallelSpec) Validate(ctx context.Context) *apis.FieldError
type ParallelStatus ¶
type ParallelStatus struct {
// inherits duck/v1 Status, which currently provides:
// * ObservedGeneration - the 'Generation' of the Service that was last processed by the controller.
// * Conditions - the latest available observations of a resource's current state.
duckv1.Status `json:",inline"`
// IngressChannelStatus corresponds to the ingress channel status.
IngressChannelStatus ParallelChannelStatus `json:"ingressChannelStatus"`
// BranchStatuses is an array of corresponding to branch statuses.
// Matches the Spec.Branches array in the order.
BranchStatuses []ParallelBranchStatus `json:"branchStatuses"`
// AddressStatus is the starting point to this Parallel. Sending to this
// will target the first subscriber.
// It generally has the form {channel}.{namespace}.svc.{cluster domain name}
duckv1.AddressStatus `json:",inline"`
}
ParallelStatus represents the current state of a Parallel.
func (*ParallelStatus) ClearDeprecated ¶
func (ps *ParallelStatus) ClearDeprecated()
ClearDeprecated removes the StatusConditionTypeDeprecated warning condition. Note that this does not affect the Ready condition.
func (*ParallelStatus) DeepCopy ¶
func (in *ParallelStatus) DeepCopy() *ParallelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelStatus.
func (*ParallelStatus) DeepCopyInto ¶
func (in *ParallelStatus) DeepCopyInto(out *ParallelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ParallelStatus) GetCondition ¶
func (ps *ParallelStatus) GetCondition(t apis.ConditionType) *apis.Condition
GetCondition returns the condition currently associated with the given type, or nil.
func (*ParallelStatus) InitializeConditions ¶
func (ps *ParallelStatus) InitializeConditions()
InitializeConditions sets relevant unset conditions to Unknown state.
func (*ParallelStatus) IsReady ¶
func (ps *ParallelStatus) IsReady() bool
IsReady returns true if the resource is ready overall.
func (*ParallelStatus) MarkAddressableNotReady ¶
func (ps *ParallelStatus) MarkAddressableNotReady(reason, messageFormat string, messageA ...interface{})
func (*ParallelStatus) MarkChannelsNotReady ¶
func (ps *ParallelStatus) MarkChannelsNotReady(reason, messageFormat string, messageA ...interface{})
func (*ParallelStatus) MarkDestinationDeprecatedRef ¶
func (ps *ParallelStatus) MarkDestinationDeprecatedRef(reason, msg string)
MarkDeprecated adds a warning condition that this object's spec is using deprecated fields and will stop working in the future. Note that this does not affect the Ready condition.
func (*ParallelStatus) MarkSubscriptionsNotReady ¶
func (ps *ParallelStatus) MarkSubscriptionsNotReady(reason, messageFormat string, messageA ...interface{})
func (*ParallelStatus) PropagateChannelStatuses ¶
func (ps *ParallelStatus) PropagateChannelStatuses(ingressChannel *duckv1alpha1.Channelable, channels []*duckv1alpha1.Channelable)
PropagateChannelStatuses sets the ChannelStatuses and ParallelConditionChannelsReady based on the status of the incoming channels.
func (*ParallelStatus) PropagateSubscriptionStatuses ¶
func (ps *ParallelStatus) PropagateSubscriptionStatuses(filterSubscriptions []*messagingv1alpha1.Subscription, subscriptions []*messagingv1alpha1.Subscription)
PropagateSubscriptionStatuses sets the ParallelConditionSubscriptionsReady based on the status of the incoming subscriptions.
type ParallelSubscriptionStatus ¶
type ParallelSubscriptionStatus struct {
// Subscription is the reference to the underlying Subscription.
Subscription corev1.ObjectReference `json:"subscription"`
// ReadyCondition indicates whether the Subscription is ready or not.
ReadyCondition apis.Condition `json:"ready"`
}
func (*ParallelSubscriptionStatus) DeepCopy ¶
func (in *ParallelSubscriptionStatus) DeepCopy() *ParallelSubscriptionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ParallelSubscriptionStatus.
func (*ParallelSubscriptionStatus) DeepCopyInto ¶
func (in *ParallelSubscriptionStatus) DeepCopyInto(out *ParallelSubscriptionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Sequence ¶
type Sequence struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// Spec defines the desired state of the Sequence.
Spec SequenceSpec `json:"spec,omitempty"`
// Status represents the current state of the Sequence. This data may be out of
// date.
// +optional
Status SequenceStatus `json:"status,omitempty"`
}
+genclient +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object Sequence defines a sequence of Subscribers that will be wired in series through Channels and Subscriptions.
func (*Sequence) ConvertFrom ¶ added in v0.13.0
ConvertFrom implements apis.Convertible Converts obj from v1beta1.Sequence into v1alpha1.Sequence
func (*Sequence) ConvertTo ¶ added in v0.13.0
ConvertTo implements apis.Convertible Converts obj from v1alpha1.Sequence into v1beta1.Sequence
func (*Sequence) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Sequence.
func (*Sequence) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Sequence) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Sequence) GetGroupVersionKind ¶
func (p *Sequence) GetGroupVersionKind() schema.GroupVersionKind
GetGroupVersionKind returns GroupVersionKind for InMemoryChannels
func (*Sequence) GetUntypedSpec ¶
func (s *Sequence) GetUntypedSpec() interface{}
GetUntypedSpec returns the spec of the Sequence.
func (*Sequence) SetDefaults ¶
type SequenceChannelStatus ¶
type SequenceChannelStatus struct {
// Channel is the reference to the underlying channel.
Channel corev1.ObjectReference `json:"channel"`
// ReadyCondition indicates whether the Channel is ready or not.
ReadyCondition apis.Condition `json:"ready"`
}
func (*SequenceChannelStatus) DeepCopy ¶
func (in *SequenceChannelStatus) DeepCopy() *SequenceChannelStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceChannelStatus.
func (*SequenceChannelStatus) DeepCopyInto ¶
func (in *SequenceChannelStatus) DeepCopyInto(out *SequenceChannelStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SequenceList ¶
type SequenceList struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
Items []Sequence `json:"items"`
}
SequenceList is a collection of Sequences.
func (*SequenceList) DeepCopy ¶
func (in *SequenceList) DeepCopy() *SequenceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceList.
func (*SequenceList) DeepCopyInto ¶
func (in *SequenceList) DeepCopyInto(out *SequenceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SequenceList) DeepCopyObject ¶
func (in *SequenceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SequenceSpec ¶
type SequenceSpec struct {
// Steps is the list of Destinations (processors / functions) that will be called in the order
// provided.
Steps []SequenceStep `json:"steps"`
// ChannelTemplate specifies which Channel CRD to use. If left unspecified, it is set to the default Channel CRD
// for the namespace (or cluster, in case there are no defaults for the namespace).
// +optional
ChannelTemplate *messagingv1beta1.ChannelTemplateSpec `json:"channelTemplate,omitempty"`
// Reply is a Reference to where the result of the last Subscriber gets sent to.
// +optional
Reply *duckv1.Destination `json:"reply,omitempty"`
}
func (*SequenceSpec) DeepCopy ¶
func (in *SequenceSpec) DeepCopy() *SequenceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceSpec.
func (*SequenceSpec) DeepCopyInto ¶
func (in *SequenceSpec) DeepCopyInto(out *SequenceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SequenceSpec) SetDefaults ¶
func (ss *SequenceSpec) SetDefaults(ctx context.Context)
func (*SequenceSpec) Validate ¶
func (ps *SequenceSpec) Validate(ctx context.Context) *apis.FieldError
type SequenceStatus ¶
type SequenceStatus struct {
// inherits duck/v1 Status, which currently provides:
// * ObservedGeneration - the 'Generation' of the Service that was last processed by the controller.
// * Conditions - the latest available observations of a resource's current state.
duckv1.Status `json:",inline"`
// SubscriptionStatuses is an array of corresponding Subscription statuses.
// Matches the Spec.Steps array in the order.
SubscriptionStatuses []SequenceSubscriptionStatus `json:"subscriptionStatuses"`
// ChannelStatuses is an array of corresponding Channel statuses.
// Matches the Spec.Steps array in the order.
ChannelStatuses []SequenceChannelStatus `json:"channelStatuses"`
// AddressStatus is the starting point to this Sequence. Sending to this
// will target the first subscriber.
// It generally has the form {channel}.{namespace}.svc.{cluster domain name}
duckv1.AddressStatus `json:",inline"`
}
SequenceStatus represents the current state of a Sequence.
func (*SequenceStatus) DeepCopy ¶
func (in *SequenceStatus) DeepCopy() *SequenceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceStatus.
func (*SequenceStatus) DeepCopyInto ¶
func (in *SequenceStatus) DeepCopyInto(out *SequenceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SequenceStatus) GetCondition ¶
func (ss *SequenceStatus) GetCondition(t apis.ConditionType) *apis.Condition
GetCondition returns the condition currently associated with the given type, or nil.
func (*SequenceStatus) InitializeConditions ¶
func (ss *SequenceStatus) InitializeConditions()
InitializeConditions sets relevant unset conditions to Unknown state.
func (*SequenceStatus) IsReady ¶
func (ss *SequenceStatus) IsReady() bool
IsReady returns true if the resource is ready overall.
func (*SequenceStatus) MarkAddressableNotReady ¶
func (ss *SequenceStatus) MarkAddressableNotReady(reason, messageFormat string, messageA ...interface{})
func (*SequenceStatus) MarkChannelsNotReady ¶
func (ss *SequenceStatus) MarkChannelsNotReady(reason, messageFormat string, messageA ...interface{})
func (*SequenceStatus) MarkSubscriptionsNotReady ¶
func (ss *SequenceStatus) MarkSubscriptionsNotReady(reason, messageFormat string, messageA ...interface{})
func (*SequenceStatus) PropagateChannelStatuses ¶
func (ss *SequenceStatus) PropagateChannelStatuses(channels []*duckv1alpha1.Channelable)
PropagateChannelStatuses sets the ChannelStatuses and SequenceConditionChannelsReady based on the status of the incoming channels.
func (*SequenceStatus) PropagateSubscriptionStatuses ¶
func (ss *SequenceStatus) PropagateSubscriptionStatuses(subscriptions []*messagingv1alpha1.Subscription)
PropagateSubscriptionStatuses sets the SubscriptionStatuses and SequenceConditionSubscriptionsReady based on the status of the incoming subscriptions.
type SequenceStep ¶ added in v0.13.0
type SequenceStep struct {
// Subscriber receiving the step event
duckv1.Destination `json:",inline"`
// Delivery is the delivery specification for events to the subscriber
// This includes things like retries, DLQ, etc.
// Needed for Roundtripping v1alpha1 <-> v1beta1.
// +optional
Delivery *eventingduckv1beta1.DeliverySpec `json:"delivery,omitempty"`
}
func (*SequenceStep) DeepCopy ¶ added in v0.13.0
func (in *SequenceStep) DeepCopy() *SequenceStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceStep.
func (*SequenceStep) DeepCopyInto ¶ added in v0.13.0
func (in *SequenceStep) DeepCopyInto(out *SequenceStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SequenceStep) SetDefaults ¶ added in v0.13.0
func (ss *SequenceStep) SetDefaults(ctx context.Context)
func (*SequenceStep) Validate ¶ added in v0.13.0
func (ss *SequenceStep) Validate(ctx context.Context) *apis.FieldError
type SequenceSubscriptionStatus ¶
type SequenceSubscriptionStatus struct {
// Subscription is the reference to the underlying Subscription.
Subscription corev1.ObjectReference `json:"subscription"`
// ReadyCondition indicates whether the Subscription is ready or not.
ReadyCondition apis.Condition `json:"ready"`
}
func (*SequenceSubscriptionStatus) DeepCopy ¶
func (in *SequenceSubscriptionStatus) DeepCopy() *SequenceSubscriptionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SequenceSubscriptionStatus.
func (*SequenceSubscriptionStatus) DeepCopyInto ¶
func (in *SequenceSubscriptionStatus) DeepCopyInto(out *SequenceSubscriptionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.