Documentation
¶
Index ¶
- func NewFilteredParallelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredSequenceInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewParallelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewSequenceInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type Interface
- type ParallelInformer
- type SequenceInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredParallelInformer ¶
func NewFilteredParallelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredParallelInformer constructs a new informer for Parallel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredSequenceInformer ¶
func NewFilteredSequenceInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredSequenceInformer constructs a new informer for Sequence type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewParallelInformer ¶
func NewParallelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewParallelInformer constructs a new informer for Parallel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewSequenceInformer ¶
func NewSequenceInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewSequenceInformer constructs a new informer for Sequence type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// Parallels returns a ParallelInformer.
Parallels() ParallelInformer
// Sequences returns a SequenceInformer.
Sequences() SequenceInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type ParallelInformer ¶
type ParallelInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ParallelLister
}
ParallelInformer provides access to a shared informer and lister for Parallels.
type SequenceInformer ¶
type SequenceInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.SequenceLister
}
SequenceInformer provides access to a shared informer and lister for Sequences.