Documentation
¶
Index ¶
- func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredInMemoryChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewInMemoryChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ChannelInformer
- type InMemoryChannelInformer
- type Interface
- type SubscriptionInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChannelInformer ¶ added in v0.8.0
func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredChannelInformer ¶ added in v0.8.0
func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredInMemoryChannelInformer ¶
func NewFilteredInMemoryChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredInMemoryChannelInformer constructs a new informer for InMemoryChannel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredSubscriptionInformer ¶ added in v0.9.0
func NewFilteredSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredSubscriptionInformer constructs a new informer for Subscription type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewInMemoryChannelInformer ¶
func NewInMemoryChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewInMemoryChannelInformer constructs a new informer for InMemoryChannel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewSubscriptionInformer ¶ added in v0.9.0
func NewSubscriptionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewSubscriptionInformer constructs a new informer for Subscription type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ChannelInformer ¶ added in v0.8.0
type ChannelInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ChannelLister
}
ChannelInformer provides access to a shared informer and lister for Channels.
type InMemoryChannelInformer ¶
type InMemoryChannelInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.InMemoryChannelLister
}
InMemoryChannelInformer provides access to a shared informer and lister for InMemoryChannels.
type Interface ¶
type Interface interface {
// Channels returns a ChannelInformer.
Channels() ChannelInformer
// InMemoryChannels returns a InMemoryChannelInformer.
InMemoryChannels() InMemoryChannelInformer
// Subscriptions returns a SubscriptionInformer.
Subscriptions() SubscriptionInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type SubscriptionInformer ¶ added in v0.9.0
type SubscriptionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.SubscriptionLister
}
SubscriptionInformer provides access to a shared informer and lister for Subscriptions.