Documentation
¶
Index ¶
- type ApiServerSourceLister
- type ApiServerSourceListerExpansion
- type ApiServerSourceNamespaceLister
- type ApiServerSourceNamespaceListerExpansion
- type ContainerSourceLister
- type ContainerSourceListerExpansion
- type ContainerSourceNamespaceLister
- type ContainerSourceNamespaceListerExpansion
- type PingSourceLister
- type PingSourceListerExpansion
- type PingSourceNamespaceLister
- type PingSourceNamespaceListerExpansion
- type SinkBindingLister
- type SinkBindingListerExpansion
- type SinkBindingNamespaceLister
- type SinkBindingNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiServerSourceLister ¶
type ApiServerSourceLister interface {
// List lists all ApiServerSources in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ApiServerSource, err error)
// ApiServerSources returns an object that can list and get ApiServerSources.
ApiServerSources(namespace string) ApiServerSourceNamespaceLister
ApiServerSourceListerExpansion
}
ApiServerSourceLister helps list ApiServerSources. All objects returned here must be treated as read-only.
func NewApiServerSourceLister ¶
func NewApiServerSourceLister(indexer cache.Indexer) ApiServerSourceLister
NewApiServerSourceLister returns a new ApiServerSourceLister.
type ApiServerSourceListerExpansion ¶
type ApiServerSourceListerExpansion interface{}
ApiServerSourceListerExpansion allows custom methods to be added to ApiServerSourceLister.
type ApiServerSourceNamespaceLister ¶
type ApiServerSourceNamespaceLister interface {
// List lists all ApiServerSources in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ApiServerSource, err error)
// Get retrieves the ApiServerSource from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.ApiServerSource, error)
ApiServerSourceNamespaceListerExpansion
}
ApiServerSourceNamespaceLister helps list and get ApiServerSources. All objects returned here must be treated as read-only.
type ApiServerSourceNamespaceListerExpansion ¶
type ApiServerSourceNamespaceListerExpansion interface{}
ApiServerSourceNamespaceListerExpansion allows custom methods to be added to ApiServerSourceNamespaceLister.
type ContainerSourceLister ¶ added in v0.14.0
type ContainerSourceLister interface {
// List lists all ContainerSources in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ContainerSource, err error)
// ContainerSources returns an object that can list and get ContainerSources.
ContainerSources(namespace string) ContainerSourceNamespaceLister
ContainerSourceListerExpansion
}
ContainerSourceLister helps list ContainerSources. All objects returned here must be treated as read-only.
func NewContainerSourceLister ¶ added in v0.14.0
func NewContainerSourceLister(indexer cache.Indexer) ContainerSourceLister
NewContainerSourceLister returns a new ContainerSourceLister.
type ContainerSourceListerExpansion ¶ added in v0.14.0
type ContainerSourceListerExpansion interface{}
ContainerSourceListerExpansion allows custom methods to be added to ContainerSourceLister.
type ContainerSourceNamespaceLister ¶ added in v0.14.0
type ContainerSourceNamespaceLister interface {
// List lists all ContainerSources in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ContainerSource, err error)
// Get retrieves the ContainerSource from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.ContainerSource, error)
ContainerSourceNamespaceListerExpansion
}
ContainerSourceNamespaceLister helps list and get ContainerSources. All objects returned here must be treated as read-only.
type ContainerSourceNamespaceListerExpansion ¶ added in v0.14.0
type ContainerSourceNamespaceListerExpansion interface{}
ContainerSourceNamespaceListerExpansion allows custom methods to be added to ContainerSourceNamespaceLister.
type PingSourceLister ¶
type PingSourceLister interface {
// List lists all PingSources in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.PingSource, err error)
// PingSources returns an object that can list and get PingSources.
PingSources(namespace string) PingSourceNamespaceLister
PingSourceListerExpansion
}
PingSourceLister helps list PingSources. All objects returned here must be treated as read-only.
func NewPingSourceLister ¶
func NewPingSourceLister(indexer cache.Indexer) PingSourceLister
NewPingSourceLister returns a new PingSourceLister.
type PingSourceListerExpansion ¶
type PingSourceListerExpansion interface{}
PingSourceListerExpansion allows custom methods to be added to PingSourceLister.
type PingSourceNamespaceLister ¶
type PingSourceNamespaceLister interface {
// List lists all PingSources in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.PingSource, err error)
// Get retrieves the PingSource from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.PingSource, error)
PingSourceNamespaceListerExpansion
}
PingSourceNamespaceLister helps list and get PingSources. All objects returned here must be treated as read-only.
type PingSourceNamespaceListerExpansion ¶
type PingSourceNamespaceListerExpansion interface{}
PingSourceNamespaceListerExpansion allows custom methods to be added to PingSourceNamespaceLister.
type SinkBindingLister ¶
type SinkBindingLister interface {
// List lists all SinkBindings in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.SinkBinding, err error)
// SinkBindings returns an object that can list and get SinkBindings.
SinkBindings(namespace string) SinkBindingNamespaceLister
SinkBindingListerExpansion
}
SinkBindingLister helps list SinkBindings. All objects returned here must be treated as read-only.
func NewSinkBindingLister ¶
func NewSinkBindingLister(indexer cache.Indexer) SinkBindingLister
NewSinkBindingLister returns a new SinkBindingLister.
type SinkBindingListerExpansion ¶
type SinkBindingListerExpansion interface{}
SinkBindingListerExpansion allows custom methods to be added to SinkBindingLister.
type SinkBindingNamespaceLister ¶
type SinkBindingNamespaceLister interface {
// List lists all SinkBindings in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.SinkBinding, err error)
// Get retrieves the SinkBinding from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.SinkBinding, error)
SinkBindingNamespaceListerExpansion
}
SinkBindingNamespaceLister helps list and get SinkBindings. All objects returned here must be treated as read-only.
type SinkBindingNamespaceListerExpansion ¶
type SinkBindingNamespaceListerExpansion interface{}
SinkBindingNamespaceListerExpansion allows custom methods to be added to SinkBindingNamespaceLister.