Documentation
¶
Overview ¶
This package has the automatically generated fake clientset.
Index ¶
- Variables
- type Clientset
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) EventingV1() eventingv1.EventingV1Interface
- func (c *Clientset) EventingV1alpha1() eventingv1alpha1.EventingV1alpha1Interface
- func (c *Clientset) EventingV1beta1() eventingv1beta1.EventingV1beta1Interface
- func (c *Clientset) EventingV1beta2() eventingv1beta2.EventingV1beta2Interface
- func (c *Clientset) EventingV1beta3() eventingv1beta3.EventingV1beta3Interface
- func (c *Clientset) FlowsV1() flowsv1.FlowsV1Interface
- func (c *Clientset) IsWatchListSemanticsUnSupported() bool
- func (c *Clientset) MessagingV1() messagingv1.MessagingV1Interface
- func (c *Clientset) SinksV1alpha1() sinksv1alpha1.SinksV1alpha1Interface
- func (c *Clientset) SourcesV1() sourcesv1.SourcesV1Interface
- func (c *Clientset) SourcesV1alpha1() sourcesv1alpha1.SourcesV1alpha1Interface
- func (c *Clientset) SourcesV1beta2() sourcesv1beta2.SourcesV1beta2Interface
- func (c *Clientset) Tracker() testing.ObjectTracker
Constants ¶
This section is empty.
Variables ¶
var AddToScheme = localSchemeBuilder.AddToScheme
AddToScheme adds all types of this clientset into the given scheme. This allows composition of clientsets, like in:
import ( "k8s.io/client-go/kubernetes" clientsetscheme "k8s.io/client-go/kubernetes/scheme" aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme" ) kclientset, _ := kubernetes.NewForConfig(c) _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
After this, RawExtensions in Kubernetes types will serialize kube-aggregator types correctly.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
Clientset implements clientset.Interface. Meant to be embedded into a struct to get a default implementation. This makes faking out just the method you want to test easier.
func NewSimpleClientset ¶
NewSimpleClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any field management, validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
func (*Clientset) EventingV1 ¶ added in v0.16.0
func (c *Clientset) EventingV1() eventingv1.EventingV1Interface
EventingV1 retrieves the EventingV1Client
func (*Clientset) EventingV1alpha1 ¶
func (c *Clientset) EventingV1alpha1() eventingv1alpha1.EventingV1alpha1Interface
EventingV1alpha1 retrieves the EventingV1alpha1Client
func (*Clientset) EventingV1beta1 ¶ added in v0.13.0
func (c *Clientset) EventingV1beta1() eventingv1beta1.EventingV1beta1Interface
EventingV1beta1 retrieves the EventingV1beta1Client
func (*Clientset) EventingV1beta2 ¶ added in v0.38.0
func (c *Clientset) EventingV1beta2() eventingv1beta2.EventingV1beta2Interface
EventingV1beta2 retrieves the EventingV1beta2Client
func (*Clientset) EventingV1beta3 ¶ added in v0.40.0
func (c *Clientset) EventingV1beta3() eventingv1beta3.EventingV1beta3Interface
EventingV1beta3 retrieves the EventingV1beta3Client
func (*Clientset) FlowsV1 ¶ added in v0.16.0
func (c *Clientset) FlowsV1() flowsv1.FlowsV1Interface
FlowsV1 retrieves the FlowsV1Client
func (*Clientset) IsWatchListSemanticsUnSupported ¶ added in v0.49.0
IsWatchListSemanticsSupported informs the reflector that this client doesn't support WatchList semantics.
This is a synthetic method whose sole purpose is to satisfy the optional interface check performed by the reflector. Returning true signals that WatchList can NOT be used. No additional logic is implemented here.
func (*Clientset) MessagingV1 ¶ added in v0.16.0
func (c *Clientset) MessagingV1() messagingv1.MessagingV1Interface
MessagingV1 retrieves the MessagingV1Client
func (*Clientset) SinksV1alpha1 ¶ added in v0.42.0
func (c *Clientset) SinksV1alpha1() sinksv1alpha1.SinksV1alpha1Interface
SinksV1alpha1 retrieves the SinksV1alpha1Client
func (*Clientset) SourcesV1 ¶ added in v0.19.0
func (c *Clientset) SourcesV1() sourcesv1.SourcesV1Interface
SourcesV1 retrieves the SourcesV1Client
func (*Clientset) SourcesV1alpha1 ¶ added in v0.6.0
func (c *Clientset) SourcesV1alpha1() sourcesv1alpha1.SourcesV1alpha1Interface
SourcesV1alpha1 retrieves the SourcesV1alpha1Client
func (*Clientset) SourcesV1beta2 ¶ added in v0.20.0
func (c *Clientset) SourcesV1beta2() sourcesv1beta2.SourcesV1beta2Interface
SourcesV1beta2 retrieves the SourcesV1beta2Client
func (*Clientset) Tracker ¶ added in v0.10.0
func (c *Clientset) Tracker() testing.ObjectTracker