Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IntegrationSourceLister ¶ added in v0.44.0
type IntegrationSourceLister interface {
// List lists all IntegrationSources in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sourcesv1alpha1.IntegrationSource, err error)
// IntegrationSources returns an object that can list and get IntegrationSources.
IntegrationSources(namespace string) IntegrationSourceNamespaceLister
IntegrationSourceListerExpansion
}
IntegrationSourceLister helps list IntegrationSources. All objects returned here must be treated as read-only.
func NewIntegrationSourceLister ¶ added in v0.44.0
func NewIntegrationSourceLister(indexer cache.Indexer) IntegrationSourceLister
NewIntegrationSourceLister returns a new IntegrationSourceLister.
type IntegrationSourceListerExpansion ¶ added in v0.44.0
type IntegrationSourceListerExpansion interface{}
IntegrationSourceListerExpansion allows custom methods to be added to IntegrationSourceLister.
type IntegrationSourceNamespaceLister ¶ added in v0.44.0
type IntegrationSourceNamespaceLister interface {
// List lists all IntegrationSources in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sourcesv1alpha1.IntegrationSource, err error)
// Get retrieves the IntegrationSource from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*sourcesv1alpha1.IntegrationSource, error)
IntegrationSourceNamespaceListerExpansion
}
IntegrationSourceNamespaceLister helps list and get IntegrationSources. All objects returned here must be treated as read-only.
type IntegrationSourceNamespaceListerExpansion ¶ added in v0.44.0
type IntegrationSourceNamespaceListerExpansion interface{}
IntegrationSourceNamespaceListerExpansion allows custom methods to be added to IntegrationSourceNamespaceLister.
Click to show internal directories.
Click to hide internal directories.