Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiServerSourceLister ¶
type ApiServerSourceLister interface {
// List lists all ApiServerSources in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ApiServerSource, err error)
// ApiServerSources returns an object that can list and get ApiServerSources.
ApiServerSources(namespace string) ApiServerSourceNamespaceLister
ApiServerSourceListerExpansion
}
ApiServerSourceLister helps list ApiServerSources. All objects returned here must be treated as read-only.
func NewApiServerSourceLister ¶
func NewApiServerSourceLister(indexer cache.Indexer) ApiServerSourceLister
NewApiServerSourceLister returns a new ApiServerSourceLister.
type ApiServerSourceListerExpansion ¶
type ApiServerSourceListerExpansion interface{}
ApiServerSourceListerExpansion allows custom methods to be added to ApiServerSourceLister.
type ApiServerSourceNamespaceLister ¶
type ApiServerSourceNamespaceLister interface {
// List lists all ApiServerSources in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ApiServerSource, err error)
// Get retrieves the ApiServerSource from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ApiServerSource, error)
ApiServerSourceNamespaceListerExpansion
}
ApiServerSourceNamespaceLister helps list and get ApiServerSources. All objects returned here must be treated as read-only.
type ApiServerSourceNamespaceListerExpansion ¶
type ApiServerSourceNamespaceListerExpansion interface{}
ApiServerSourceNamespaceListerExpansion allows custom methods to be added to ApiServerSourceNamespaceLister.
type SinkBindingLister ¶ added in v0.11.0
type SinkBindingLister interface {
// List lists all SinkBindings in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SinkBinding, err error)
// SinkBindings returns an object that can list and get SinkBindings.
SinkBindings(namespace string) SinkBindingNamespaceLister
SinkBindingListerExpansion
}
SinkBindingLister helps list SinkBindings. All objects returned here must be treated as read-only.
func NewSinkBindingLister ¶ added in v0.11.0
func NewSinkBindingLister(indexer cache.Indexer) SinkBindingLister
NewSinkBindingLister returns a new SinkBindingLister.
type SinkBindingListerExpansion ¶ added in v0.11.0
type SinkBindingListerExpansion interface{}
SinkBindingListerExpansion allows custom methods to be added to SinkBindingLister.
type SinkBindingNamespaceLister ¶ added in v0.11.0
type SinkBindingNamespaceLister interface {
// List lists all SinkBindings in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SinkBinding, err error)
// Get retrieves the SinkBinding from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.SinkBinding, error)
SinkBindingNamespaceListerExpansion
}
SinkBindingNamespaceLister helps list and get SinkBindings. All objects returned here must be treated as read-only.
type SinkBindingNamespaceListerExpansion ¶ added in v0.11.0
type SinkBindingNamespaceListerExpansion interface{}
SinkBindingNamespaceListerExpansion allows custom methods to be added to SinkBindingNamespaceLister.